psutil: Python library to retrieve information on processes and system utilization
==================================================================================

Description
-----------

psutil is a cross-platform library for retrieving information on running
processes and system utilization (CPU, memory, disks, network) in
Python.

License
-------

3-clause BSD license


Upstream Contact
----------------

https://github.com/giampaolo/psutil/
